////////////////////////////////////////////////////////////////////////////////
//
// Export.h
//
//! \file
//! \brief Declare class or functions as exportable
//!
//! Declare class or functions as exportable only when included from the defining CPP file
//! If we use common Windows practice, we are open to erroneous Template instanciations
//! especially of destructors of std::auto_ptr or TAutoPtr \n
//! So : \n
//!	  \li The project will define LIBA_EXPORTS (as usual)
//!		\li The CPP file that want to define the class must include following sequence
//!   \code
//!		      #define LIBA_DO_EXPORTS
//!		      #include <xxxx.h>
//!		      #undef LIBA_DO_EXPORTS
//!   \endcode
//!		\li The   xxxx.h file must include the xxxxExport file (THIS file)
//!
//! \n Copyright (C) 2004 ActiCM. All rights reserved.
//
////////////////////////////////////////////////////////////////////////////////

//! \def LIBA_API
//! \brief Macro d'import/export des symboles du module.
#ifdef _WIN32
#    ifdef LIBA_EXPORTS
#         undef LIBA_API
#		  ifdef LIBA_DO_EXPORTS
#             define  LIBA_API __declspec(dllexport)
#         else
#             define  LIBA_API
#         endif
#    else
#         define LIBA_API __declspec(dllimport)
#    endif
//--------------------
#  else  // _WIN32
#    define LIBA_API 
#endif // _WIN32